@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "gravatarconfiguresettingsdialog.h"
@@ -22,14 +9,12 @@
 #include "misc/gravatarcache.h"
 #include <PimCommon/ConfigureImmutableWidgetUtils>
 
+#include "gravatarsettings.h"
 #include <KLocalizedString>
-#include <KPluralHandlingSpinBox>
-#include <KSeparator>
 #include <QCheckBox>
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <QVBoxLayout>
-#include "gravatarsettings.h"
 using namespace Gravatar;
 using namespace PimCommon::ConfigureImmutableWidgetUtils;
 
@@ -37,14 +22,14 @@ GravatarConfigureSettingsDialog::GravatarConfigureSettingsDialog(QWidget *parent
     : QDialog(parent)
 {
     setWindowTitle(i18nc("@title:window", "Configure Gravatar"));
-    QVBoxLayout *topLayout = new QVBoxLayout(this);
+    auto topLayout = new QVBoxLayout(this);
     topLayout->setObjectName(QStringLiteral("toplayout"));
 
     mGravatarConfigureSettings = new GravatarConfigureSettingsWidget(this);
     mGravatarConfigureSettings->setObjectName(QStringLiteral("gravatarconfiguresettings"));
     topLayout->addWidget(mGravatarConfigureSettings);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::RestoreDefaults, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::RestoreDefaults, this);
     buttonBox->setObjectName(QStringLiteral("buttonbox"));
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -57,9 +42,7 @@ GravatarConfigureSettingsDialog::GravatarConfigureSettingsDialog(QWidget *parent
     load();
 }
 
-GravatarConfigureSettingsDialog::~GravatarConfigureSettingsDialog()
-{
-}
+GravatarConfigureSettingsDialog::~GravatarConfigureSettingsDialog() = default;
 
 void GravatarConfigureSettingsDialog::slotRestoreDefault()
 {
@@ -76,4 +59,3 @@ void GravatarConfigureSettingsDialog::load()
 {
     mGravatarConfigureSettings->load();
 }
-
