@@ -1,40 +1,27 @@
 /*
-   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "gravatardownloadpixmapwidget.h"
 #include "gravatar/gravatarresolvurljob.h"
 #include "gravatar_debug.h"
-#include <QLabel>
 #include <KLocalizedString>
-#include <QVBoxLayout>
+#include <QCheckBox>
+#include <QLabel>
 #include <QLineEdit>
 #include <QPushButton>
-#include <QCheckBox>
+#include <QVBoxLayout>
 
 using namespace Gravatar;
 GravatarDownloadPixmapWidget::GravatarDownloadPixmapWidget(QWidget *parent)
     : QWidget(parent)
 {
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
-    QHBoxLayout *hbox = new QHBoxLayout;
+    auto mainLayout = new QVBoxLayout(this);
+    auto hbox = new QHBoxLayout;
     mainLayout->addLayout(hbox);
-    QLabel *lab = new QLabel(i18n("Email:"));
+    auto lab = new QLabel(i18n("Email:"));
     lab->setObjectName(QStringLiteral("labemail"));
     hbox->addWidget(lab);
     mLineEdit = new QLineEdit;
@@ -42,6 +29,14 @@ GravatarDownloadPixmapWidget::GravatarDownloadPixmapWidget(QWidget *parent)
     connect(mLineEdit, &QLineEdit::textChanged, this, &GravatarDownloadPixmapWidget::slotTextChanged);
     hbox->addWidget(mLineEdit);
 
+    mUseLibravatar = new QCheckBox(i18n("Use Libravatar"));
+    mUseLibravatar->setObjectName(QStringLiteral("uselibravatar"));
+    mainLayout->addWidget(mUseLibravatar);
+
+    mFallbackGravatar = new QCheckBox(i18n("Fallback to Gravatar"));
+    mFallbackGravatar->setObjectName(QStringLiteral("fallbackgravatar"));
+    mainLayout->addWidget(mFallbackGravatar);
+
     mGetPixmapButton = new QPushButton(i18n("&Search"));
     mGetPixmapButton->setObjectName(QStringLiteral("searchbutton"));
     connect(mGetPixmapButton, &QAbstractButton::clicked, this, &GravatarDownloadPixmapWidget::slotSearchButton);
@@ -56,9 +51,7 @@ GravatarDownloadPixmapWidget::GravatarDownloadPixmapWidget(QWidget *parent)
     mainLayout->addWidget(mResultLabel);
 }
 
-GravatarDownloadPixmapWidget::~GravatarDownloadPixmapWidget()
-{
-}
+GravatarDownloadPixmapWidget::~GravatarDownloadPixmapWidget() = default;
 
 QPixmap GravatarDownloadPixmapWidget::gravatarPixmap() const
 {
@@ -82,10 +75,12 @@ void GravatarDownloadPixmapWidget::slotResolvUrlFinish(Gravatar::GravatarResolvU
 void GravatarDownloadPixmapWidget::slotSearchButton()
 {
     mResultLabel->setText(QString());
-    Gravatar::GravatarResolvUrlJob *job = new Gravatar::GravatarResolvUrlJob(this);
+    auto job = new Gravatar::GravatarResolvUrlJob(this);
     job->setEmail(mLineEdit->text());
-    //For testing
-    //job->setUseDefaultPixmap(true);
+    // For testing
+    // job->setUseDefaultPixmap(true);
+    job->setUseLibravatar(mUseLibravatar->isChecked());
+    job->setFallbackGravatar(mFallbackGravatar->isChecked());
     if (job->canStart()) {
         connect(job, &GravatarResolvUrlJob::finished, this, &GravatarDownloadPixmapWidget::slotResolvUrlFinish);
         job->start();
